# Instruções para Executar o Projeto com Docker

Este guia descreve os passos para construir e executar os contêineres Docker para um projeto que inclui um banco de dados PostgreSQL e um servidor backend Node.js.

## Pré-requisitos

- [Docker](https://www.docker.com/get-started) instalado em seu sistema.

## Passo 1: Construir o Contêiner PostgreSQL

Primeiro, você deve construir o contêiner Docker para o PostgreSQL usando o arquivo Dockerfile.postgres.


`npm run build-db`


Este comando irá construir um contêiner com o nome "postgres-eu-luto" usando as instruções no Dockerfile.postgres. Certifique-se de executar este comando na mesma pasta onde o Dockerfile.postgres está localizado.

## Passo 2: Construir o Contêiner Backend Node.js

Agora, você deve construir o contêiner Docker para o servidor backend Node.js usando o arquivo Dockerfile.node.


`npm run build-node`


Isso irá construir um contêiner com o nome "backend-eu-luto" usando as instruções no Dockerfile.node. Certifique-se de executar este comando na mesma pasta onde o Dockerfile.node está localizado.

## Passo 3: Iniciar os Contêineres Usando o Docker Compose

Após construir os contêineres, você pode iniciá-los usando o Docker Compose. Certifique-se de ter um arquivo docker-compose.yml configurado para o seu projeto com as configurações apropriadas para o banco de dados PostgreSQL e o servidor Node.js.


`npm run start:build`


Este comando irá iniciar os contêineres com base no arquivo docker-compose.yml presente no diretório atual.

## Conclusão

Agora, o seu projeto deve estar em execução com os contêineres Docker do PostgreSQL e do Node.js. Você pode acessar o servidor Node.js em [http://localhost:3000](http://localhost:3000) e o banco de dados PostgreSQL conforme configurado no arquivo docker-compose.yml.

Lembre-se de ajustar as configurações e nomes dos contêineres de acordo com o seu projeto específico.




## Para testar

Este guia fornece instruções sobre como executar e testar o projeto usando Docker e npm.

## Requisitos

Antes de começar, certifique-se de ter o seguinte instalado em seu sistema:

- Node.js: https://nodejs.org/
- Docker: https://www.docker.com/

## Instruções de Execução

Siga os passos abaixo para executar e testar o projeto:

### Passo 1: Inicializar o Contêiner do Banco de Dados (Docker)

Abra um terminal e navegue até a raiz do projeto:

`cd /caminho/para/o/seu/projeto`

Certifique-se de que o Docker esteja em execução em seu sistema e execute o seguinte comando para iniciar o contêiner do banco de dados:

`npm run start:docker-db`

Isso irá iniciar um contêiner Docker com um banco de dados configurado para o projeto.

### Passo 2: Instalar as Dependências do Projeto
Abra outro terminal (mantenha o terminal do contêiner do banco de dados aberto) e navegue até a raiz do projeto:

`cd /caminho/para/o/seu/projeto`

Instale as dependências do projeto usando npm:

`npm install`

### Passo 3: Executar os Testes
Agora, você pode executar os testes do projeto usando o seguinte comando:

`npm run test`

Isso executará os testes automatizados e fornecerá os resultados no terminal.

Após a conclusão dos testes, você pode continuar desenvolvendo e testando seu projeto conforme necessário.

Lembre-se de parar o contêiner Docker do banco de dados quando não estiver mais em uso:

npm run stop:docker-db