-- CreateEnum
CREATE TYPE "EventStatus" AS ENUM ('AVAILABLE', 'WAITING_CONFIRMATION', 'CONFIRMED', 'CANCELLED', 'FINISHED', 'MISSED', 'EXPIRED');

-- CreateEnum
CREATE TYPE "EvenType" AS ENUM ('INTEGRATIVE_THERAPY', 'PSYCHOTHERAPY');

-- CreateTable
CREATE TABLE "events" (
    "id" SERIAL NOT NULL,
    "authorId" INTEGER NOT NULL,
    "pacientId" INTEGER,
    "eventType" "EvenType",
    "name" TEXT,
    "date" TIMESTAMP(3) NOT NULL,
    "startTime" TEXT NOT NULL,
    "endTime" TEXT NOT NULL,
    "status" "EventStatus",
    "active" BOOLEAN NOT NULL,
    "updatedAt" TIMESTAMP(3),

    CONSTRAINT "events_pkey" PRIMARY KEY ("id")
);

-- CreateTable
CREATE TABLE "notifications" (
    "id" SERIAL NOT NULL,
    "userId" INTEGER,
    "title" TEXT,
    "description" TEXT,
    "createdAt" TIMESTAMP(3) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "sentAt" TIMESTAMP(3),
    "updatedAt" TIMESTAMP(3) NOT NULL,

    CONSTRAINT "notifications_pkey" PRIMARY KEY ("id")
);

-- CreateTable
CREATE TABLE "users" (
    "id" SERIAL NOT NULL,
    "email" TEXT NOT NULL,
    "phone" TEXT,
    "region" TEXT,
    "losingPhase" TEXT,
    "username" TEXT,
    "password" TEXT NOT NULL,
    "active" BOOLEAN,
    "userType" INTEGER,
    "createdAt" TIMESTAMP(3) DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" TIMESTAMP(3),
    "childName" TEXT,
    "gender" TEXT,

    CONSTRAINT "users_pkey" PRIMARY KEY ("id")
);

-- AddForeignKey
ALTER TABLE "events" ADD CONSTRAINT "events_authorId_fkey" FOREIGN KEY ("authorId") REFERENCES "users"("id") ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE "events" ADD CONSTRAINT "events_pacientId_fkey" FOREIGN KEY ("pacientId") REFERENCES "users"("id") ON DELETE SET NULL ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE "notifications" ADD CONSTRAINT "notifications_userId_fkey" FOREIGN KEY ("userId") REFERENCES "users"("id") ON DELETE SET NULL ON UPDATE CASCADE;
