import express, { NextFunction, Request, Response } from "express";
import bodyParser from "body-parser";
import dotenv from 'dotenv';
import router from './routes/index';
import { logger } from './logger';
dotenv.config();

const app = express();
const port = process.env.PORT || 3000;

app.use((req: Request, res: Response, next) => {
  logger.info(`Received ${req.method} request at ${req.url}`);
  next();
});

app.use(bodyParser.json());
app.use(router);


app.listen(port, () => {
  logger.info(`Server is running on port ${port}`);
});

app.use((err: Error, req: Request, res: Response) => {
  logger.error(`Error: ${err.message}`);
  res.status(500).json({ error: 'Internal Server Error' });
});
