import request from 'supertest';
import express from 'express';
import { registerUserController } from './userController';
import * as userService from '../../services/user/userService';

const app = express();
app.use(express.json());

app.post('/register', registerUserController);

describe('registerUserController', () => {
  it('should return success message and user ID on successful registration', async () => {
    const randomEmail = Math.random().toString(36).substring(2, 15) + '@gmail.com';
    const userId = '000000000001'
    const mockUserData = {
        strEmail: randomEmail,
        strUsername: 'a',
        strPassword: 'a',
        confirmPassword: 'a',
        nUserType: 1,
    };

    jest.spyOn(userService, 'registerUser').mockResolvedValueOnce(userId);

    const response = await request(app)
      .post('/register')
      .send(mockUserData);

    expect(userService.registerUser).toHaveBeenCalledWith(mockUserData);
    expect(response.status).toBe(200);
    expect(response.body).toEqual({ message: 'User registered successfully', userId });
  });

});
