import winston from 'winston';

const customTimestamp = new Date().toLocaleString('pt-BR', { timeZone: 'America/Sao_Paulo' });

export const logger = winston.createLogger({
  format: winston.format.combine(
    winston.format.timestamp({ format: customTimestamp }),
    winston.format.printf(({ timestamp, level, message, meta }) => {
      let logMessage = `${timestamp} [${level}]: ${message}`;
      if (meta) {
        const circularSafeMeta = circularSafeStringify(meta);
        logMessage += `\n${circularSafeMeta}`;
      }
      return logMessage;
    })
  ),
  transports: [
    new winston.transports.Console(),
    new winston.transports.File({ filename: 'log/app.log' }),
  ],
});

function circularSafeStringify(obj: any): string {
  const seen = new WeakSet();
  return JSON.stringify(obj, (key, value) => {
    if (typeof value === 'object' && value !== null) {
      if (seen.has(value)) {
        return '[Circular]';
      }
      seen.add(value);
    }
    return value;
  }, 2);
}
