import { Request, Response, NextFunction } from "express";
import jwt from "jsonwebtoken";
import dotenv from "dotenv";

dotenv.config();

const setUserIdFromBody = (req: Request, res: Response, next: NextFunction) => {
  const token: string = req.headers.authorization || "";
  const jwtSecret = process.env.JWT_SECRET;

  if (!jwtSecret) {
    return res.status(500).json({ error: "JWT secret is not defined" });
  }

  jwt.verify(token, jwtSecret, (err: any, decoded: any) => {
    if (err) {
      return res.status(401).json({ error: "Unauthorized" });
    }

    const { nUserId, accessLevel }: { nUserId: number; accessLevel: number } =
      decoded;

    (req as any).body.nUserId = nUserId;

    if (accessLevel === 0) {
      (req as any).body.accessAllowed = true;
    } else {
      (req as any).body.accessAllowed = false;
    }

    next();
  });
};

export default setUserIdFromBody;
