import { Request, Response, NextFunction } from 'express';
import jwt, { VerifyErrors, Secret } from 'jsonwebtoken';

const secretKey: Secret = '-auth-secret-key';

interface DecodedToken {
  userId: string;
  accessLevel: number;
}

export default function authenticateToken(req: Request, res: Response, next: NextFunction) {
  const token = req.headers.authorization;

  if (!token) {
    return res.status(401).json({ message: 'Authorization token not provided' });
  }

  jwt.verify(token, secretKey, (err: VerifyErrors | null, decodedToken: any) => {
    if (err) {
      return res.status(403).json({ message: 'Token invalid or expired' });
    }

    const decoded = decodedToken as DecodedToken;
    req.userId = decoded.userId;
    req.accessLevel = decoded.accessLevel;

    next();
  });
}
